@@ -1,3 +1,4 @@
+
 from click.exceptions import ClickException
 
 from mvapi.cli.project import cli
@@ -5,7 +6,6 @@ from mvapi.libs.database import db
 from mvapi.libs.error import save_error
 from mvapi.libs.logger import init_logger
 from mvapi.models import import_models
-from mvapi.settings import settings
 from mvapi.web.libs.appfactory import create_app
 from mvapi.web.serializers import import_serializers
 from mvapi.web.views import import_views
@@ -15,9 +15,9 @@ def run_app(cli_=cli):
     import_models()
     import_views()
     import_serializers()
+    init_logger()
 
     if not cli_:
-        init_logger(settings.DEBUG)
         return create_app()
     else:
         try:
